# Changelog

## [0.3.1](https://github.com/CoreySpohn/exoverses/compare/v0.3.0...v0.3.1) (2025-12-15)


### Bug Fixes

* Refactor ExoVista classes to use units consistently ([8d63b1d](https://github.com/CoreySpohn/exoverses/commit/8d63b1d93ace5cc9d7f928869a0472a0f79bea7e))

## [0.3.0](https://github.com/CoreySpohn/exoverses/compare/v0.2.3...v0.3.0) (2025-06-26)


### Features

* Enhance ExovistaDisk initialization with header data ([3565ca8](https://github.com/CoreySpohn/exoverses/commit/3565ca86843276823d7036d556b32e23284ae361))

## [0.2.3](https://github.com/CoreySpohn/exoverses/compare/v0.2.2...v0.2.3) (2024-12-01)


### Bug Fixes

* Add filtering flags to exovista universe ([81e3e9d](https://github.com/CoreySpohn/exoverses/commit/81e3e9df9cf7bee5008977f0049833cc4b14d69c))
* **main:** Removed hardcoded exovista universe cache directory ([d0cad18](https://github.com/CoreySpohn/exoverses/commit/d0cad181491b50d61407167904a52e023c5abc8c))
* Transition from interp2d to RectBivariateSpline ([45fe6cd](https://github.com/CoreySpohn/exoverses/commit/45fe6cd136c1e71124b065dbfb8216fc643c7b04))

## [0.2.2](https://github.com/CoreySpohn/exoverses/compare/v0.2.1...v0.2.2) (2024-04-19)


### Bug Fixes

* **main:** Improved the has_planets property, better planet classification string ([cf71a73](https://github.com/CoreySpohn/exoverses/commit/cf71a735a772c310f315c38b366d14c75f66de1f))

## [0.2.1](https://github.com/CoreySpohn/exoverses/compare/v0.2.0...v0.2.1) (2024-04-03)


### Bug Fixes

* **main:** Remove usage of deprecated open_text importlib.resources method ([4e77086](https://github.com/CoreySpohn/exoverses/commit/4e77086b372a0a02d4ce9608b8e0b151aa7fa86c))

## [0.2.0](https://github.com/CoreySpohn/exoverses/compare/v0.1.1...v0.2.0) (2024-04-03)


### Features

* **main:** Add Kopparapu bins based on EXOSIMS implementation ([d49dd76](https://github.com/CoreySpohn/exoverses/commit/d49dd763af9c73d13e1dd7387a0940abc9976f15))


### Bug Fixes

* cleaning up target list to remove duplicate HIP values to match the stars in the large ExoVista target list ([cb4106f](https://github.com/CoreySpohn/exoverses/commit/cb4106fd3f7c2793b25c01e32190aa27ee749b70))
* fixing formatting of the util init file for importing ([2067963](https://github.com/CoreySpohn/exoverses/commit/206796310d98e7f28207dc0c39abed23595abcde))
* incorrect import statement in the util ([0c5460a](https://github.com/CoreySpohn/exoverses/commit/0c5460a506a0e2bf3b7791625a06e5259ef7cddc))
* **main:** Added system name property ([592edc2](https://github.com/CoreySpohn/exoverses/commit/592edc20f93f0021538738994afe46cb28da2c73))
